%define anolis_release 3
%bcond_with docs
%bcond_without tests

Name:           python-virtualenv
Version:        20.16.5
Release:        %{anolis_release}%{?dist}
Summary:        Tool to create isolated Python environments

License:        MIT
URL:            http://pypi.python.org/pypi/virtualenv
Source0:        %{pypi_source virtualenv}

Patch1001:	1001-change-the-package-version-for-sysom.patch
Patch0001:      0001-bugfix-rpm-wheels-error.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-distlib
BuildRequires:  python3-filelock
BuildRequires:  python3-platformdirs
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  python3-six

# docs need sphinx >= 3
# docs need towncrier and that is not yet available when bootstrapping Python
%if %{with docs}
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  python3-towncrier
%endif

%if %{with tests}
BuildRequires:  fish
BuildRequires:  tcsh
BuildRequires:  gcc
BuildRequires:  python3-flaky
BuildRequires:  python3-packaging
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-mock
BuildRequires:  python3-pytest-randomly
BuildRequires:  python3-pytest-timeout
%endif

# RPM installed wheels
BuildRequires:  python-pip-wheel
BuildRequires:  python-setuptools-wheel
BuildRequires:  python3-wheel

Requires:       python-wheel-wheel

%description
virtualenv is a tool to create isolated Python environments. virtualenv
is a successor to workingenv, and an extension of virtual-python. It is
written by Ian Bicking, and sponsored by the Open Planning Project. It is
licensed under an MIT-style permissive license.


%package -n     python3-virtualenv
Summary:        Tool to create isolated Python environments
Conflicts:      python3.10 < 3.10.0-3
Obsoletes:      python3-virtualenv-python26 < 16.6
%{?python_provide:%python_provide python3-virtualenv}
Provides:       virtualenv = %{version}-%{release}

# RPM installed wheels
Requires:       python-pip-wheel
Requires:       python-setuptools-wheel
Requires:       python3-wheel

%description -n python3-virtualenv
virtualenv is a tool to create isolated Python environments. virtualenv
is a successor to workingenv, and an extension of virtual-python. It is
written by Ian Bicking, and sponsored by the Open Planning Project. It is
licensed under an MIT-style permissive license

%package -n     python3-virtualenv-doc
Summary:        Documentation for python virtualenv

%description -n python3-virtualenv-doc
Documentation for python virtualenv.

%prep
%autosetup -p1 -n virtualenv-%{version}

# Remove the wheels provided by RPM packages
rm src/virtualenv/seed/wheels/embed/pip-*
rm src/virtualenv/seed/wheels/embed/setuptools-*
rm src/virtualenv/seed/wheels/embed/wheel-*

test ! -f src/virtualenv/seed/embed/wheels/*.whl
#sed -i "s|/usr/share/python-wheels|%{python_wheel_dir}|" src/virtualenv/util/path/_system_wheels.py

%build
# Build code
%{py3_build}

# Build docs
%if %{with docs}
PYTHONPATH=src %{python3} setup.py build_sphinx
rm -f build/sphinx/html/.buildinfo
%endif

%install
%{py3_install}
mv %{buildroot}%{_bindir}/virtualenv{,-%{python3_version}}
ln -s virtualenv-%{python3_version} %{buildroot}%{_bindir}/virtualenv-3
ln -s virtualenv-3 %{buildroot}%{_bindir}/virtualenv

%if %{with tests}
%check
mkdir tmp_path
ln -s $(realpath %{__python3}) tmp_path/python
export PATH="$(pwd)/tmp_path:$PATH"
unset SOURCE_DATE_EPOCH

# Skip tests which requires internet or some extra dependencies
# Requires internet:
# - test_download_*
# Uses disabled functionalities around bundled wheels:
# - test_wheel_*
# - test_creator_*
# - test_bootstrap_link_via_app_data
# - test_build_c_ext
# - test_session_report_full
# - test_seed_link_via_app_data
# - test_base_bootstrap_via_pip_invoke
# - test_acquire.py (whole file)
# - test_bundle.py (whole file)
# Uses disabled functionalities around automatic updates:
# - test_periodic_update.py (whole file)
PIP_CERT=/etc/pki/tls/certs/ca-bundle.crt \
%pytest -vv -k "not test_bundle and not test_acquire and not test_periodic_update and not test_wheel_ and not test_download_ and not test_base_bootstrap_via_pip_invoke and not test_seed_link_via_app_data and not test_creator and not test_bootstrap_link_via_app_data and not test_build_c_ext and not test_session_report_full"

rm -r tmp_path
%endif

%files -n python3-virtualenv
%license LICENSE
%{_bindir}/virtualenv-%{python3_version}
%{_bindir}/virtualenv
%{_bindir}/virtualenv-3
%{python3_sitelib}/virtualenv/
%{python3_sitelib}/virtualenv-*.egg-info/

%files -n python3-virtualenv-doc
%doc docs/*rst README.md
%if %{with docs}
%doc build/sphinx/*
%endif

%changelog
* Thu Oct 13 2022 happy_orange <songnannan@linux.alibaba.com> - 20.16.5-3
- change the python dist for sysom

* Thu Oct 13 2022 happy_orange <songnannan@linux.alibaba.com> - 20.16.5-2
- add virtualenv-3 binary for sysom

* Thu Oct 13 2022 happy_orange <songnannan@linux.alibaba.com> - 20.16.5-1
- Init pacakge from upstream

